==> wormhole-query-sdk-0.0.1.tgz: package/lib/esm/query/request.js <==
import { BinaryWriter } from "./BinaryWriter";
import { utils } from "web3";
import { hexToUint8Array } from "./utils";
export const MAINNET_QUERY_REQUEST_PREFIX = "mainnet_query_request_000000000000|";
export const TESTNET_QUERY_REQUEST_PREFIX = "testnet_query_request_000000000000|";
export const DEVNET_QUERY_REQUEST_PREFIX = "devnet_query_request_0000000000000|";
export function getPrefix(network) {
    return network === "MAINNET"
        ? MAINNET_QUERY_REQUEST_PREFIX
        : network === "TESTNET"
            ? TESTNET_QUERY_REQUEST_PREFIX
            : DEVNET_QUERY_REQUEST_PREFIX;
}
export class QueryRequest {
    constructor(nonce, requests = [], version = 1) {
        this.nonce = nonce;
        this.requests = requests;
        this.version = version;
    }
    serialize() {
        const writer = new BinaryWriter()
            .writeUint8(this.version)
            .writeUint32(this.nonce)
            .writeUint8(this.requests.length);
        this.requests.forEach((request) => writer.writeUint8Array(request.serialize()));
        return writer.data();
    }
    static digest(network, bytes) {
        const prefix = getPrefix(network);
        const data = Buffer.concat([Buffer.from(prefix), bytes]);
        return hexToUint8Array(utils.keccak256(data).slice(2));
    }
}
export class PerChainQueryRequest {
    constructor(chainId, query) {
        this.chainId = chainId;
        this.query = query;
    }
    serialize() {
        const writer = new BinaryWriter()
            .writeUint16(this.chainId)
            .writeUint8(this.query.type());
        const queryData = this.query.serialize();
        return writer
            .writeUint32(queryData.length)
            .writeUint8Array(queryData)
            .data();
    }
}
export var ChainQueryType;
(function (ChainQueryType) {
    ChainQueryType[ChainQueryType["EthCall"] = 1] = "EthCall";
    ChainQueryType[ChainQueryType["EthCallByTimeStamp"] = 2] = "EthCallByTimeStamp";
})(ChainQueryType || (ChainQueryType = {}));

==> wormhole-query-sdk-0.0.2.tgz: package/lib/esm/query/request.js <==
import { keccak256 } from "@ethersproject/keccak256";
import { BinaryWriter } from "./BinaryWriter";
import { hexToUint8Array } from "./utils";
export const MAINNET_QUERY_REQUEST_PREFIX = "mainnet_query_request_000000000000|";
export const TESTNET_QUERY_REQUEST_PREFIX = "testnet_query_request_000000000000|";
export const DEVNET_QUERY_REQUEST_PREFIX = "devnet_query_request_0000000000000|";
export function getPrefix(network) {
    return network === "MAINNET"
        ? MAINNET_QUERY_REQUEST_PREFIX
        : network === "TESTNET"
            ? TESTNET_QUERY_REQUEST_PREFIX
            : DEVNET_QUERY_REQUEST_PREFIX;
}
export class QueryRequest {
    constructor(nonce, requests = [], version = 1) {
        this.nonce = nonce;
        this.requests = requests;
        this.version = version;
    }
    serialize() {
        const writer = new BinaryWriter()
            .writeUint8(this.version)
            .writeUint32(this.nonce)
            .writeUint8(this.requests.length);
        this.requests.forEach((request) => writer.writeUint8Array(request.serialize()));
        return writer.data();
    }
    static digest(network, bytes) {
        const prefix = getPrefix(network);
        const data = Buffer.concat([Buffer.from(prefix), bytes]);
        return hexToUint8Array(keccak256(data).slice(2));
    }
}
export class PerChainQueryRequest {
    constructor(chainId, query) {
        this.chainId = chainId;
        this.query = query;
    }
    serialize() {
        const writer = new BinaryWriter()
            .writeUint16(this.chainId)
            .writeUint8(this.query.type());
        const queryData = this.query.serialize();
        return writer
            .writeUint32(queryData.length)
            .writeUint8Array(queryData)
            .data();
    }
}
export var ChainQueryType;
(function (ChainQueryType) {
    ChainQueryType[ChainQueryType["EthCall"] = 1] = "EthCall";
    ChainQueryType[ChainQueryType["EthCallByTimeStamp"] = 2] = "EthCallByTimeStamp";
})(ChainQueryType || (ChainQueryType = {}));
